'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Actions = require('../Actions');

var _ActionBar = require('./ActionBar.scss');

var _ActionBar2 = _interopRequireDefault(_ActionBar);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var DISPLAY_MODES = {
	DROPDOWN: 'dropdown',
	SPLIT_DROPDOWN: 'splitDropdown',
	BTN_GROUP: 'btnGroup'
};

var actionsShape = {
	left: _propTypes2.default.arrayOf(_propTypes2.default.oneOfType([_propTypes2.default.shape(_Actions.Action.propTypes), _propTypes2.default.shape(_Actions.ActionSplitDropdown.propTypes)])),
	right: _propTypes2.default.arrayOf(_propTypes2.default.oneOfType([_propTypes2.default.shape(_Actions.Action.propTypes), _propTypes2.default.shape(_Actions.ActionSplitDropdown.propTypes)])),
	children: _propTypes2.default.node
};

function getRenderers(props) {
	return _extends({
		Action: _Actions.Action,
		Actions: _Actions.Actions,
		ActionDropdown: _Actions.ActionDropdown,
		ActionSplitDropdown: _Actions.ActionSplitDropdown
	}, props ? props.renderers : {});
}

function getActionsToRender(_ref) {
	var selected = _ref.selected,
	    actions = _ref.actions,
	    multiSelectActions = _ref.multiSelectActions;

	if (selected > 0) {
		return multiSelectActions || {};
	}
	return actions || {};
}

function getContentClassName(_ref2) {
	var _classNames;

	var tag = _ref2.tag,
	    className = _ref2.className,
	    left = _ref2.left,
	    right = _ref2.right;

	return (0, _classnames2.default)(className, (_classNames = {}, _defineProperty(_classNames, '' + _ActionBar2.default['navbar-left'], left), _defineProperty(_classNames, '' + _ActionBar2.default['navbar-right'], right), _defineProperty(_classNames, 'navbar-left', left), _defineProperty(_classNames, 'navbar-right', right), _defineProperty(_classNames, 'navbar-text', tag === 'p'), _defineProperty(_classNames, 'navbar-btn', tag === 'button'), _defineProperty(_classNames, 'navbar-form', tag === 'form'), _defineProperty(_classNames, 'navbar-link', tag === 'a'), _classNames));
}

function Content(_ref3) {
	var _ref3$tag = _ref3.tag,
	    tag = _ref3$tag === undefined ? 'div' : _ref3$tag,
	    left = _ref3.left,
	    right = _ref3.right,
	    className = _ref3.className,
	    children = _ref3.children,
	    rest = _objectWithoutProperties(_ref3, ['tag', 'left', 'right', 'className', 'children']);

	var props = _extends({
		className: getContentClassName({ tag: tag, left: left, right: right, className: className })
	}, rest);
	return _react2.default.createElement(tag, props, children);
}
Content.propTypes = {
	children: _propTypes2.default.node,
	className: _propTypes2.default.string,
	left: _propTypes2.default.bool,
	right: _propTypes2.default.bool,
	tag: _propTypes2.default.oneOf(['p', 'button', 'form', 'a', 'div'])
};

function SwitchActions(_ref4) {
	var actions = _ref4.actions,
	    left = _ref4.left,
	    right = _ref4.right,
	    selected = _ref4.selected,
	    renderers = _ref4.renderers;

	var Renderers = getRenderers({ renderers: renderers });
	return _react2.default.createElement(
		Content,
		{ left: left, right: right },
		selected > 0 && !right ? _react2.default.createElement(Count, { selected: selected }) : null,
		actions.map(function (action, index) {
			var displayMode = action.displayMode,
			    rest = _objectWithoutProperties(action, ['displayMode']);

			switch (displayMode) {
				case DISPLAY_MODES.DROPDOWN:
					return _react2.default.createElement(Renderers.ActionDropdown, _extends({ key: index }, rest));
				case DISPLAY_MODES.SPLIT_DROPDOWN:
					return _react2.default.createElement(Renderers.ActionSplitDropdown, _extends({ key: index }, rest));
				case DISPLAY_MODES.BTN_GROUP:
					return _react2.default.createElement(Renderers.Actions, _extends({ key: index }, rest));
				default:
					return _react2.default.createElement(Renderers.Action, _extends({ key: index }, rest));
			}
		})
	);
}
SwitchActions.propTypes = {
	actions: _propTypes2.default.arrayOf(_propTypes2.default.shape(actionsShape)).isRequired,
	left: _propTypes2.default.bool,
	right: _propTypes2.default.bool,
	selected: _propTypes2.default.number,
	renderers: _propTypes2.default.shape({
		Action: _propTypes2.default.func,
		Actions: _propTypes2.default.func,
		ActionSplitDropdown: _propTypes2.default.func
	})
};
SwitchActions.defaultProps = {
	actions: []
};

function Count(_ref5) {
	var selected = _ref5.selected;

	if (!selected) {
		return null;
	}
	return _react2.default.createElement(
		'span',
		{ className: (0, _classnames2.default)(_ActionBar2.default['tc-actionbar-selected-count'], 'tc-actionbar-selected-count') },
		selected,
		' selected'
	);
}
Count.propTypes = {
	selected: _propTypes2.default.number
};

function ActionBar(props) {
	var _getActionsToRender = getActionsToRender(props),
	    left = _getActionsToRender.left,
	    right = _getActionsToRender.right;

	var cssClass = (0, _classnames2.default)(_ActionBar2.default['tc-actionbar-container'], 'tc-actionbar-container', 'nav', props.className);
	return _react2.default.createElement(
		'nav',
		{ className: cssClass },
		(left || !!props.selected) && _react2.default.createElement(SwitchActions, {
			renderers: props.renderers,
			key: 0,
			actions: left,
			selected: props.selected,
			left: true
		}),
		props.children,
		right && _react2.default.createElement(SwitchActions, {
			renderers: props.renderers,
			key: 1,
			actions: right,
			selected: props.selected,
			right: true
		})
	);
}

ActionBar.propTypes = {
	selected: _propTypes2.default.number,
	children: _propTypes2.default.node,
	className: _propTypes2.default.string,
	renderers: _propTypes2.default.shape(SwitchActions.propTypes.renderers)
};

ActionBar.displayName = 'ActionBar';
ActionBar.DISPLAY_MODES = DISPLAY_MODES;
ActionBar.Count = Count;
ActionBar.SwitchActions = SwitchActions;
ActionBar.getActionsToRender = getActionsToRender;
ActionBar.Content = Content;
ActionBar.getContentClassName = getContentClassName;
ActionBar.getRenderers = getRenderers;
exports.default = ActionBar;