'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _VirtualizedList = require('../../VirtualizedList');

var _VirtualizedList2 = _interopRequireDefault(_VirtualizedList);

var _CellTitle = require('../../VirtualizedList/CellTitle');

var _CellTitle2 = _interopRequireDefault(_CellTitle);

var _CellActions = require('../../VirtualizedList/CellActions');

var _CellActions2 = _interopRequireDefault(_CellActions);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function adaptOnSort(onChange) {
	if (!onChange) {
		return null;
	}
	return function onSortChange(_ref) {
		var sortBy = _ref.sortBy,
		    sortDirection = _ref.sortDirection;

		return onChange(null, { field: sortBy, isDescending: sortDirection === _VirtualizedList.SORT_BY.DESC });
	};
}

function ListToVirtualizedList(props) {
	var itemProps = props.itemProps,
	    sort = props.sort,
	    titleProps = props.titleProps;


	if (!titleProps.actionsKey) {
		titleProps.actionsKey = 'actions';
	}
	// Backward compatibility: find array in object attr:
	var supposedActions = {};
	if (props.items.length > 0) {
		var item = props.items[0];
		Object.keys(item).filter(function (key) {
			return Array.isArray(item[key]);
		}).forEach(function (key) {
			supposedActions[key] = true;
		});
	}
	return _react2.default.createElement(
		_VirtualizedList2.default,
		{
			id: props.id,
			collection: props.items,
			isActive: itemProps && itemProps.isActive,
			isSelected: itemProps && itemProps.isSelected,
			onRowClick: itemProps && itemProps.onRowClick,
			selectionToggle: itemProps && itemProps.onToggle,
			sort: adaptOnSort(sort && sort.onChange),
			sortBy: sort && sort.field,
			sortDirection: sort && sort.isDescending ? _VirtualizedList.SORT_BY.DESC : _VirtualizedList.SORT_BY.ASC,
			type: props.displayMode.toUpperCase()
		},
		props.columns.map(function (column, index) {
			var cProps = {
				label: column.label,
				dataKey: column.key
			};
			if (column.key === titleProps.key) {
				_extends(cProps, _CellTitle2.default, {
					columnData: titleProps
				});
			}
			if (supposedActions[column.key]) {
				_extends(cProps, _CellActions2.default);
			}
			return _react2.default.createElement(_VirtualizedList2.default.Content, _extends({ key: index }, cProps));
		})
	);
}

ListToVirtualizedList.propTypes = {
	id: _propTypes2.default.string,
	columns: _propTypes2.default.arrayOf(_propTypes2.default.object),
	displayMode: _propTypes2.default.oneOf(['large', 'table']),
	itemProps: _propTypes2.default.shape({
		isActive: _propTypes2.default.func,
		isSelected: _propTypes2.default.func,
		onRowClick: _propTypes2.default.func,
		onToggle: _propTypes2.default.func
	}),
	items: _propTypes2.default.arrayOf(_propTypes2.default.object),
	sort: _propTypes2.default.shape({
		onChange: _propTypes2.default.func,
		field: _propTypes2.default.string,
		isDescending: _propTypes2.default.bool
	}),
	titleProps: _propTypes2.default.shape({
		actionsKey: _propTypes2.default.string,
		key: _propTypes2.default.string
	})
};
ListToVirtualizedList.defaultProps = {
	displayMode: 'table'
};

exports.default = ListToVirtualizedList;