'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.renderItem = exports.renderSectionTitle = exports.renderItemsContainerFactory = exports.renderInputComponent = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _ControlLabel = require('react-bootstrap/lib/ControlLabel');

var _ControlLabel2 = _interopRequireDefault(_ControlLabel);

var _FormControl = require('react-bootstrap/lib/FormControl');

var _FormControl2 = _interopRequireDefault(_FormControl);

var _reactDebounceInput = require('react-debounce-input');

var _reactDebounceInput2 = _interopRequireDefault(_reactDebounceInput);

var _Icon = require('../Icon');

var _Icon2 = _interopRequireDefault(_Icon);

var _CircularProgress = require('../CircularProgress');

var _CircularProgress2 = _interopRequireDefault(_CircularProgress);

var _Emphasis = require('../Emphasis');

var _Emphasis2 = _interopRequireDefault(_Emphasis);

var _Typeahead = require('./Typeahead.scss');

var _Typeahead2 = _interopRequireDefault(_Typeahead);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var renderInputComponent = exports.renderInputComponent = function renderInputComponent(props) {
	var key = props.key,
	    debounceMinLength = props.debounceMinLength,
	    debounceTimeout = props.debounceTimeout,
	    icon = props.icon,
	    rest = _objectWithoutProperties(props, ['key', 'debounceMinLength', 'debounceTimeout', 'icon']);

	var renderedIcon = icon && _react2.default.createElement(
		'div',
		{ className: _Typeahead2.default['icon-cls'] },
		_react2.default.createElement(_Icon2.default, { name: icon.name, title: icon.title })
	);

	return _react2.default.createElement(
		'div',
		{ className: _Typeahead2.default['typeahead-input-icon'] },
		_react2.default.createElement(
			_ControlLabel2.default,
			{ srOnly: true, htmlFor: key },
			'Search'
		),
		debounceMinLength || debounceTimeout ? _react2.default.createElement(_reactDebounceInput2.default, _extends({
			id: key
		}, rest, {
			autoFocus: true,
			element: _FormControl2.default,
			minLength: debounceMinLength,
			debounceTimeout: debounceTimeout
		})) : _react2.default.createElement(_FormControl2.default, _extends({
			id: key,
			autoFocus: true
		}, rest)),
		renderedIcon
	);
};
renderInputComponent.propTypes = {
	key: _propTypes2.default.string,
	debounceMinLength: _propTypes2.default.number,
	debounceTimeout: _propTypes2.default.number,
	icon: _propTypes2.default.shape({
		name: _propTypes2.default.string,
		title: _propTypes2.default.string
	})
};

var ItemContainer = function ItemContainer(props) {
	var items = props.items,
	    noResultText = props.noResultText,
	    searching = props.searching,
	    searchingText = props.searchingText,
	    containerProps = _objectWithoutProperties(props, ['items', 'noResultText', 'searching', 'searchingText']);

	var className = containerProps.className,
	    restProps = _objectWithoutProperties(containerProps, ['className']);

	if (searching) {
		return _react2.default.createElement(
			'div',
			_extends({ className: className + ' ' + _Typeahead2.default['is-searching'] }, restProps),
			_react2.default.createElement(
				'span',
				{ className: 'is-searching' },
				searchingText
			),
			' ',
			_react2.default.createElement(_CircularProgress2.default, null)
		);
	}
	if (items && !items.length) {
		return _react2.default.createElement(
			'div',
			_extends({ className: className + ' ' + _Typeahead2.default['no-result'] }, restProps),
			_react2.default.createElement(
				'span',
				{ className: 'no-result' },
				noResultText
			)
		);
	}
	return _react2.default.createElement('div', containerProps);
};
ItemContainer.propTypes = {
	className: _propTypes2.default.string,
	items: _propTypes2.default.arrayOf(_propTypes2.default.shape({
		title: _propTypes2.default.string,
		description: _propTypes2.default.string,
		suggestions: _propTypes2.default.arrayOf(_propTypes2.default.shape({
			title: _propTypes2.default.string,
			description: _propTypes2.default.string
		}))
	})),
	noResultText: _propTypes2.default.string,
	searching: _propTypes2.default.bool,
	searchingText: _propTypes2.default.string
};

var renderItemsContainerFactory = exports.renderItemsContainerFactory = function renderItemsContainerFactory(items, noResultText, searching, searchingText) {
	var renderItemsContainerComponent = function renderItemsContainerComponent(props) {
		var id = props.id,
		    key = props.key,
		    ref = props.ref,
		    rest = _objectWithoutProperties(props, ['id', 'key', 'ref']);

		return _react2.default.createElement(
			'div',
			{
				id: id,
				ref: ref,
				key: key
			},
			_react2.default.createElement(ItemContainer, _extends({}, rest, {
				items: items,
				noResultText: noResultText,
				searching: searching,
				searchingText: searchingText
			}))
		);
	};

	renderItemsContainerComponent.propTypes = {
		id: _propTypes2.default.string,
		key: _propTypes2.default.string,
		ref: _propTypes2.default.func
	};

	return renderItemsContainerComponent;
};

var renderSectionTitle = exports.renderSectionTitle = function renderSectionTitle(section) {
	if (section) {
		return _react2.default.createElement(
			'div',
			{ className: _Typeahead2.default['section-header'] },
			section.icon && _react2.default.createElement(_Icon2.default, { name: section.icon.name, title: section.icon.title }),
			_react2.default.createElement(
				'span',
				{ className: _Typeahead2.default['section-header-title'] },
				section.title
			)
		);
	}
	return null;
};

var renderItem = exports.renderItem = function renderItem(item, _ref) {
	var value = _ref.value;

	var title = item.title ? item.title.trim() : '';
	return _react2.default.createElement(
		'div',
		{ className: _Typeahead2.default.item, title: title },
		_react2.default.createElement(
			'span',
			{ className: _Typeahead2.default['item-title'] },
			_react2.default.createElement(_Emphasis2.default, { value: value, text: title })
		),
		_react2.default.createElement(
			'p',
			{ className: _Typeahead2.default['item-description'] },
			_react2.default.createElement(_Emphasis2.default, { value: value, text: item.description })
		)
	);
};