'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _reactVirtualized = require('react-virtualized');

var _RowSelection = require('../RowSelection');

var _RowSelection2 = _interopRequireDefault(_RowSelection);

var _NoRows = require('../NoRows');

var _NoRows2 = _interopRequireDefault(_NoRows);

var _tablerow = require('../utils/tablerow');

var _ListTable = require('./ListTable.scss');

var _ListTable2 = _interopRequireDefault(_ListTable);

var _RowThemes = require('./RowThemes');

var _RowThemes2 = _interopRequireDefault(_RowThemes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * List renderer that renders a react-virtualized Table
 */
function ListTable(props) {
	var children = props.children,
	    collection = props.collection,
	    height = props.height,
	    id = props.id,
	    isActive = props.isActive,
	    isSelected = props.isSelected,
	    onRowClick = props.onRowClick,
	    sort = props.sort,
	    sortBy = props.sortBy,
	    sortDirection = props.sortDirection,
	    width = props.width;


	var RowTableRenderer = // eslint-disable-line new-cap
	_reactVirtualized.defaultTableRowRenderer;
	if (isActive || isSelected) {
		RowTableRenderer = (0, _RowSelection2.default)(_reactVirtualized.defaultTableRowRenderer, {
			isSelected: isSelected,
			isActive: isActive,
			getRowData: function getRowData(rowProps) {
				return rowProps.rowData;
			}
		});
	}

	var onRowClickCallback = void 0;
	if (onRowClick) {
		onRowClickCallback = function onRowClickCallback(_ref) {
			var event = _ref.event,
			    rowData = _ref.rowData;
			return onRowClick(event, rowData);
		};
	}

	return _react2.default.createElement(
		_reactVirtualized.Table,
		{
			className: 'tc-list-table ' + _ListTable2.default['tc-list-table'],
			gridClassName: _ListTable2.default.grid,
			headerHeight: 35,
			height: height,
			id: id,
			onRowClick: onRowClickCallback,
			noRowsRenderer: _NoRows2.default,
			rowClassName: (0, _classnames2.default)(_RowThemes2.default),
			rowCount: collection.length,
			rowGetter: function rowGetter(_ref2) {
				var index = _ref2.index;
				return collection[index];
			},
			rowHeight: 50,
			rowRenderer: RowTableRenderer,
			sort: sort,
			sortBy: sortBy,
			sortDirection: sortDirection,
			width: width
		},
		(0, _tablerow.toColumns)(id, _ListTable2.default, children)
	);
}
ListTable.displayName = 'VirtualizedList(ListTable)';
ListTable.propTypes = {
	children: _propTypes2.default.arrayOf(_propTypes2.default.element),
	collection: _propTypes2.default.arrayOf(_propTypes2.default.object),
	height: _propTypes2.default.number,
	id: _propTypes2.default.string,
	isActive: _propTypes2.default.func,
	isSelected: _propTypes2.default.func,
	onRowClick: _propTypes2.default.func,
	sort: _propTypes2.default.func,
	sortBy: _propTypes2.default.string,
	sortDirection: _propTypes2.default.string,
	width: _propTypes2.default.number
};

exports.default = ListTable;